
#ifndef TIMER_H_
#define TIMER_H_

/// A helper class to simplify timing and preserve code readability.
/*! Measures and stores the time (in seconds) between a call to Start() and Stop(). The time is stored in seconds using double precision, it should therefore be sufficiently accurate. */
class Timer {
public:
/// Starts the timer.
    void Start();
    
/// Stops the timer, must be called after Start().    
    void Stop();
    
/// Retrieves the measured time in seconds between a call to Start() and Stop().
    double GetTime() const;

private:
    double m_seconds;
    static double TimeNow(); ///< Returns the current time in seconds. Used by Start() and Stop().
};

#endif /* TIMER_H_ */


