#ifndef GLOBALS_H_
#define GLOBALS_H_

/*! @file globals.h
 *  @brief Header file containing all the global variables. */

/// Enum type describing the amount of information output.
enum Output 
{ 
    ERROR, ///< Only output error messages and the end of execution results.
    INFO, ///< Output minimal, but useful information. 
    VERBOSE ///< Output everything.
};

/*! @brief Global variable that indicates if there is only one worker available for execution.
 *  Used to omit border exchanges if there is only one worker in use. Is initialized in Node.cpp and set during Worker creation. */
extern bool g_single_worker;

/*! @brief Global variable that defines the amount of information output to the screen during execution.
 *  Is initialized in main.cpp and set when loading the system configuration. */
extern Output g_output;

/*! @def use_float
 *  @brief Decides between float and double precision.
 *  A compiler flag that decides if the my_float type should use float (32-bit) or double (64-bit) precision. Double precision will be selected if this line is commented away or removed. This exists only to provide a convenient way to switch between float and double precision. */
#define use_float

#ifdef use_float
typedef float my_float;
#else
typedef double my_float;
#endif

#endif /* GLOBALS_H_ */

